==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/plugins/qmldesigner/components/propertyeditor/propertyeditortransaction.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef PROPERTYEDITORTRANSACTION_H
#define PROPERTYEDITORTRANSACTION_H

#include "propertyeditorview.h"

namespace QmlDesigner {

class PropertyEditorTransaction : public QObject
{
    Q_OBJECT
public:
    PropertyEditorTransaction(QmlDesigner::PropertyEditorView *propertyEditor);

public slots:
    void start();
    void end();
protected:
     void timerEvent(QTimerEvent *event);

private:
    QmlDesigner::PropertyEditorView *m_propertyEditor;
    QmlDesigner::RewriterTransaction m_rewriterTransaction;
    int m_timerId;
};

} //QmlDesigner

#endif // PROPERTYEDITORTRANSACTION_H

==> qt-creator-opensource-src-4.7.0.zip: qt-creator-opensource-src-4.7.0/src/plugins/qmldesigner/components/propertyeditor/propertyeditortransaction.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "propertyeditorview.h"

namespace QmlDesigner {

class PropertyEditorTransaction : public QObject
{
    Q_OBJECT
public:
    PropertyEditorTransaction(QmlDesigner::PropertyEditorView *propertyEditor);

    Q_INVOKABLE void start();
    Q_INVOKABLE void end();

protected:
     void timerEvent(QTimerEvent *event) override;

private:
    QmlDesigner::PropertyEditorView *m_propertyEditor;
    QmlDesigner::RewriterTransaction m_rewriterTransaction;
    int m_timerId;
};

} //QmlDesigner
